# Defines comfig for a "gui" system, in most cases a Desktop or Laptop
{ config, pkgs, ... }:

{
  imports = [ ./pkgs.nix ];
  
  # Basic X11/display manager config
  services.xserver = {
    enable = true;
    displayManager.sddm.enable = true;  
    desktopManager.plasma5.enable = true;
    displayManager.sddm.theme = "nx-sddm";
  };

  networking.networkmanager.enable = true;
  
  sound.enable = true;
  hardware.pulseaudio.enable = true;

  # Additional services
  services.flatpak.enable = true;
  xdg.portal.enable = true;
  xdg.portal.gtkUsePortal = true;

  # Input config
  services.xserver = {
    synaptics.tapButtons = false;
    libinput.enable = true;
  };

  # PulseAUdio networking
  hardware.pulseaudio.tcp.enable = true;
  hardware.pulseaudio.zeroconf.discovery.enable = true;
  
  # Syncthing
  services.syncthing.enable = true;
  services.syncthing.user = "chris";
  services.syncthing.configDir = "/home/chris/.config/syncthing";
  services.syncthing.dataDir = "/home/chris";

  # Printing
  services.printing.enable = true;
  services.printing.drivers = [ pkgs.gutenprint ];
  services.avahi.enable = true;
  services.avahi.nssmdns = true;
}
